# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = ['DbManagementPrivateEndpointArgs', 'DbManagementPrivateEndpoint']

@pulumi.input_type
class DbManagementPrivateEndpointArgs:
    def __init__(__self__, *,
                 compartment_id: pulumi.Input[str],
                 subnet_id: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 is_cluster: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 nsg_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None):
        """
        The set of arguments for constructing a DbManagementPrivateEndpoint resource.
        :param pulumi.Input[str] compartment_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        :param pulumi.Input[str] subnet_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] description: (Updatable) The description of the private endpoint.
        :param pulumi.Input[bool] is_cluster: Specifies whether the Database Management private endpoint will be used for Oracle Databases in a cluster.
        :param pulumi.Input[str] name: (Updatable) The display name of the Database Management private endpoint.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] nsg_ids: (Updatable) The OCIDs of the Network Security Groups to which the Database Management private endpoint belongs.
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "subnet_id", subnet_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if is_cluster is not None:
            pulumi.set(__self__, "is_cluster", is_cluster)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if nsg_ids is not None:
            pulumi.set(__self__, "nsg_ids", nsg_ids)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Input[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The description of the private endpoint.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="isCluster")
    def is_cluster(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether the Database Management private endpoint will be used for Oracle Databases in a cluster.
        """
        return pulumi.get(self, "is_cluster")

    @is_cluster.setter
    def is_cluster(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_cluster", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The display name of the Database Management private endpoint.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nsgIds")
    def nsg_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        (Updatable) The OCIDs of the Network Security Groups to which the Database Management private endpoint belongs.
        """
        return pulumi.get(self, "nsg_ids")

    @nsg_ids.setter
    def nsg_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "nsg_ids", value)


@pulumi.input_type
class _DbManagementPrivateEndpointState:
    def __init__(__self__, *,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 is_cluster: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 nsg_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 private_ip: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 subnet_id: Optional[pulumi.Input[str]] = None,
                 time_created: Optional[pulumi.Input[str]] = None,
                 vcn_id: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering DbManagementPrivateEndpoint resources.
        :param pulumi.Input[str] compartment_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        :param pulumi.Input[str] description: (Updatable) The description of the private endpoint.
        :param pulumi.Input[bool] is_cluster: Specifies whether the Database Management private endpoint will be used for Oracle Databases in a cluster.
        :param pulumi.Input[str] name: (Updatable) The display name of the Database Management private endpoint.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] nsg_ids: (Updatable) The OCIDs of the Network Security Groups to which the Database Management private endpoint belongs.
        :param pulumi.Input[str] private_ip: The IP addresses assigned to the Database Management private endpoint.
        :param pulumi.Input[str] state: The current lifecycle state of the Database Management private endpoint.
        :param pulumi.Input[str] subnet_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] time_created: The date and time the Database Managament private endpoint was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
        :param pulumi.Input[str] vcn_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN.
        """
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if is_cluster is not None:
            pulumi.set(__self__, "is_cluster", is_cluster)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if nsg_ids is not None:
            pulumi.set(__self__, "nsg_ids", nsg_ids)
        if private_ip is not None:
            pulumi.set(__self__, "private_ip", private_ip)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if subnet_id is not None:
            pulumi.set(__self__, "subnet_id", subnet_id)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)
        if vcn_id is not None:
            pulumi.set(__self__, "vcn_id", vcn_id)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The description of the private endpoint.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="isCluster")
    def is_cluster(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether the Database Management private endpoint will be used for Oracle Databases in a cluster.
        """
        return pulumi.get(self, "is_cluster")

    @is_cluster.setter
    def is_cluster(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_cluster", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The display name of the Database Management private endpoint.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nsgIds")
    def nsg_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]:
        """
        (Updatable) The OCIDs of the Network Security Groups to which the Database Management private endpoint belongs.
        """
        return pulumi.get(self, "nsg_ids")

    @nsg_ids.setter
    def nsg_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]]):
        pulumi.set(self, "nsg_ids", value)

    @property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> Optional[pulumi.Input[str]]:
        """
        The IP addresses assigned to the Database Management private endpoint.
        """
        return pulumi.get(self, "private_ip")

    @private_ip.setter
    def private_ip(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "private_ip", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current lifecycle state of the Database Management private endpoint.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> Optional[pulumi.Input[str]]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "subnet_id")

    @subnet_id.setter
    def subnet_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "subnet_id", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The date and time the Database Managament private endpoint was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)

    @property
    @pulumi.getter(name="vcnId")
    def vcn_id(self) -> Optional[pulumi.Input[str]]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN.
        """
        return pulumi.get(self, "vcn_id")

    @vcn_id.setter
    def vcn_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vcn_id", value)


class DbManagementPrivateEndpoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 is_cluster: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 nsg_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 subnet_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        This resource provides the Db Management Private Endpoint resource in Oracle Cloud Infrastructure Database Management service.

        Creates a new Database Management private endpoint.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_db_management_private_endpoint = oci.database_management.DbManagementPrivateEndpoint("testDbManagementPrivateEndpoint",
            compartment_id=var["compartment_id"],
            subnet_id=oci_core_subnet["test_subnet"]["id"],
            description=var["db_management_private_endpoint_description"],
            is_cluster=var["db_management_private_endpoint_is_cluster"],
            nsg_ids=var["db_management_private_endpoint_nsg_ids"])
        ```

        ## Import

        DbManagementPrivateEndpoints can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:DatabaseManagement/dbManagementPrivateEndpoint:DbManagementPrivateEndpoint test_db_management_private_endpoint "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        :param pulumi.Input[str] description: (Updatable) The description of the private endpoint.
        :param pulumi.Input[bool] is_cluster: Specifies whether the Database Management private endpoint will be used for Oracle Databases in a cluster.
        :param pulumi.Input[str] name: (Updatable) The display name of the Database Management private endpoint.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] nsg_ids: (Updatable) The OCIDs of the Network Security Groups to which the Database Management private endpoint belongs.
        :param pulumi.Input[str] subnet_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DbManagementPrivateEndpointArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Db Management Private Endpoint resource in Oracle Cloud Infrastructure Database Management service.

        Creates a new Database Management private endpoint.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_db_management_private_endpoint = oci.database_management.DbManagementPrivateEndpoint("testDbManagementPrivateEndpoint",
            compartment_id=var["compartment_id"],
            subnet_id=oci_core_subnet["test_subnet"]["id"],
            description=var["db_management_private_endpoint_description"],
            is_cluster=var["db_management_private_endpoint_is_cluster"],
            nsg_ids=var["db_management_private_endpoint_nsg_ids"])
        ```

        ## Import

        DbManagementPrivateEndpoints can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:DatabaseManagement/dbManagementPrivateEndpoint:DbManagementPrivateEndpoint test_db_management_private_endpoint "id"
        ```

        :param str resource_name: The name of the resource.
        :param DbManagementPrivateEndpointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DbManagementPrivateEndpointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 is_cluster: Optional[pulumi.Input[bool]] = None,
                 name: Optional[pulumi.Input[str]] = None,
                 nsg_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
                 subnet_id: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DbManagementPrivateEndpointArgs.__new__(DbManagementPrivateEndpointArgs)

            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["description"] = description
            __props__.__dict__["is_cluster"] = is_cluster
            __props__.__dict__["name"] = name
            __props__.__dict__["nsg_ids"] = nsg_ids
            if subnet_id is None and not opts.urn:
                raise TypeError("Missing required property 'subnet_id'")
            __props__.__dict__["subnet_id"] = subnet_id
            __props__.__dict__["private_ip"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["time_created"] = None
            __props__.__dict__["vcn_id"] = None
        super(DbManagementPrivateEndpoint, __self__).__init__(
            'oci:DatabaseManagement/dbManagementPrivateEndpoint:DbManagementPrivateEndpoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            is_cluster: Optional[pulumi.Input[bool]] = None,
            name: Optional[pulumi.Input[str]] = None,
            nsg_ids: Optional[pulumi.Input[Sequence[pulumi.Input[str]]]] = None,
            private_ip: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[str]] = None,
            subnet_id: Optional[pulumi.Input[str]] = None,
            time_created: Optional[pulumi.Input[str]] = None,
            vcn_id: Optional[pulumi.Input[str]] = None) -> 'DbManagementPrivateEndpoint':
        """
        Get an existing DbManagementPrivateEndpoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        :param pulumi.Input[str] description: (Updatable) The description of the private endpoint.
        :param pulumi.Input[bool] is_cluster: Specifies whether the Database Management private endpoint will be used for Oracle Databases in a cluster.
        :param pulumi.Input[str] name: (Updatable) The display name of the Database Management private endpoint.
        :param pulumi.Input[Sequence[pulumi.Input[str]]] nsg_ids: (Updatable) The OCIDs of the Network Security Groups to which the Database Management private endpoint belongs.
        :param pulumi.Input[str] private_ip: The IP addresses assigned to the Database Management private endpoint.
        :param pulumi.Input[str] state: The current lifecycle state of the Database Management private endpoint.
        :param pulumi.Input[str] subnet_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] time_created: The date and time the Database Managament private endpoint was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
        :param pulumi.Input[str] vcn_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DbManagementPrivateEndpointState.__new__(_DbManagementPrivateEndpointState)

        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["description"] = description
        __props__.__dict__["is_cluster"] = is_cluster
        __props__.__dict__["name"] = name
        __props__.__dict__["nsg_ids"] = nsg_ids
        __props__.__dict__["private_ip"] = private_ip
        __props__.__dict__["state"] = state
        __props__.__dict__["subnet_id"] = subnet_id
        __props__.__dict__["time_created"] = time_created
        __props__.__dict__["vcn_id"] = vcn_id
        return DbManagementPrivateEndpoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[str]:
        """
        (Updatable) The description of the private endpoint.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="isCluster")
    def is_cluster(self) -> pulumi.Output[bool]:
        """
        Specifies whether the Database Management private endpoint will be used for Oracle Databases in a cluster.
        """
        return pulumi.get(self, "is_cluster")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[str]:
        """
        (Updatable) The display name of the Database Management private endpoint.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nsgIds")
    def nsg_ids(self) -> pulumi.Output[Sequence[str]]:
        """
        (Updatable) The OCIDs of the Network Security Groups to which the Database Management private endpoint belongs.
        """
        return pulumi.get(self, "nsg_ids")

    @property
    @pulumi.getter(name="privateIp")
    def private_ip(self) -> pulumi.Output[str]:
        """
        The IP addresses assigned to the Database Management private endpoint.
        """
        return pulumi.get(self, "private_ip")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current lifecycle state of the Database Management private endpoint.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="subnetId")
    def subnet_id(self) -> pulumi.Output[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the subnet.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "subnet_id")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The date and time the Database Managament private endpoint was created, in the format defined by [RFC3339](https://tools.ietf.org/html/rfc3339).
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="vcnId")
    def vcn_id(self) -> pulumi.Output[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the VCN.
        """
        return pulumi.get(self, "vcn_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetMysqlConfigurationResult',
    'AwaitableGetMysqlConfigurationResult',
    'get_mysql_configuration',
    'get_mysql_configuration_output',
]

@pulumi.output_type
class GetMysqlConfigurationResult:
    """
    A collection of values returned by getMysqlConfiguration.
    """
    def __init__(__self__, compartment_id=None, configuration_id=None, defined_tags=None, description=None, display_name=None, freeform_tags=None, id=None, init_variables=None, parent_configuration_id=None, shape_name=None, state=None, time_created=None, time_updated=None, type=None, variables=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if configuration_id and not isinstance(configuration_id, str):
            raise TypeError("Expected argument 'configuration_id' to be a str")
        pulumi.set(__self__, "configuration_id", configuration_id)
        if defined_tags and not isinstance(defined_tags, dict):
            raise TypeError("Expected argument 'defined_tags' to be a dict")
        pulumi.set(__self__, "defined_tags", defined_tags)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if freeform_tags and not isinstance(freeform_tags, dict):
            raise TypeError("Expected argument 'freeform_tags' to be a dict")
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if init_variables and not isinstance(init_variables, list):
            raise TypeError("Expected argument 'init_variables' to be a list")
        pulumi.set(__self__, "init_variables", init_variables)
        if parent_configuration_id and not isinstance(parent_configuration_id, str):
            raise TypeError("Expected argument 'parent_configuration_id' to be a str")
        pulumi.set(__self__, "parent_configuration_id", parent_configuration_id)
        if shape_name and not isinstance(shape_name, str):
            raise TypeError("Expected argument 'shape_name' to be a str")
        pulumi.set(__self__, "shape_name", shape_name)
        if state and not isinstance(state, str):
            raise TypeError("Expected argument 'state' to be a str")
        pulumi.set(__self__, "state", state)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if time_updated and not isinstance(time_updated, str):
            raise TypeError("Expected argument 'time_updated' to be a str")
        pulumi.set(__self__, "time_updated", time_updated)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if variables and not isinstance(variables, list):
            raise TypeError("Expected argument 'variables' to be a list")
        pulumi.set(__self__, "variables", variables)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        OCID of the Compartment the Configuration exists in.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="configurationId")
    def configuration_id(self) -> str:
        return pulumi.get(self, "configuration_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter
    def description(self) -> str:
        """
        User-provided data about the Configuration.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        The display name of the Configuration.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The OCID of the Configuration.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="initVariables")
    def init_variables(self) -> Sequence['outputs.GetMysqlConfigurationInitVariableResult']:
        """
        User-defined service variables set only at DB system initialization. These variables cannot be changed later at runtime.
        """
        return pulumi.get(self, "init_variables")

    @property
    @pulumi.getter(name="parentConfigurationId")
    def parent_configuration_id(self) -> str:
        """
        The OCID of the Configuration from which this Configuration is "derived". This is entirely a metadata relationship. There is no relation between the values in this Configuration and its parent.
        """
        return pulumi.get(self, "parent_configuration_id")

    @property
    @pulumi.getter(name="shapeName")
    def shape_name(self) -> str:
        """
        The name of the associated Shape.
        """
        return pulumi.get(self, "shape_name")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        The current state of the Configuration.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the Configuration was created, as described by [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The date and time the Configuration was last updated, as described by [RFC 3339](https://tools.ietf.org/rfc/rfc3339).
        """
        return pulumi.get(self, "time_updated")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        The Configuration type, DEFAULT or CUSTOM.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def variables(self) -> Sequence['outputs.GetMysqlConfigurationVariableResult']:
        """
        User-defined service variables.
        """
        return pulumi.get(self, "variables")


class AwaitableGetMysqlConfigurationResult(GetMysqlConfigurationResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMysqlConfigurationResult(
            compartment_id=self.compartment_id,
            configuration_id=self.configuration_id,
            defined_tags=self.defined_tags,
            description=self.description,
            display_name=self.display_name,
            freeform_tags=self.freeform_tags,
            id=self.id,
            init_variables=self.init_variables,
            parent_configuration_id=self.parent_configuration_id,
            shape_name=self.shape_name,
            state=self.state,
            time_created=self.time_created,
            time_updated=self.time_updated,
            type=self.type,
            variables=self.variables)


def get_mysql_configuration(configuration_id: Optional[str] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMysqlConfigurationResult:
    """
    This data source provides details about a specific Mysql Configuration resource in Oracle Cloud Infrastructure MySQL Database service.

    Get the full details of the specified Configuration, including the list of MySQL Variables and their values.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_mysql_configuration = oci.Mysql.get_mysql_configuration(configuration_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str configuration_id: The OCID of the Configuration.
    """
    __args__ = dict()
    __args__['configurationId'] = configuration_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Mysql/getMysqlConfiguration:getMysqlConfiguration', __args__, opts=opts, typ=GetMysqlConfigurationResult).value

    return AwaitableGetMysqlConfigurationResult(
        compartment_id=__ret__.compartment_id,
        configuration_id=__ret__.configuration_id,
        defined_tags=__ret__.defined_tags,
        description=__ret__.description,
        display_name=__ret__.display_name,
        freeform_tags=__ret__.freeform_tags,
        id=__ret__.id,
        init_variables=__ret__.init_variables,
        parent_configuration_id=__ret__.parent_configuration_id,
        shape_name=__ret__.shape_name,
        state=__ret__.state,
        time_created=__ret__.time_created,
        time_updated=__ret__.time_updated,
        type=__ret__.type,
        variables=__ret__.variables)


@_utilities.lift_output_func(get_mysql_configuration)
def get_mysql_configuration_output(configuration_id: Optional[pulumi.Input[str]] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetMysqlConfigurationResult]:
    """
    This data source provides details about a specific Mysql Configuration resource in Oracle Cloud Infrastructure MySQL Database service.

    Get the full details of the specified Configuration, including the list of MySQL Variables and their values.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_mysql_configuration = oci.Mysql.get_mysql_configuration(configuration_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str configuration_id: The OCID of the Configuration.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['HttpRedirectArgs', 'HttpRedirect']

@pulumi.input_type
class HttpRedirectArgs:
    def __init__(__self__, *,
                 compartment_id: pulumi.Input[str],
                 domain: pulumi.Input[str],
                 target: pulumi.Input['HttpRedirectTargetArgs'],
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 response_code: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a HttpRedirect resource.
        :param pulumi.Input[str] compartment_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the HTTP Redirects compartment.
        :param pulumi.Input[str] domain: The domain from which traffic will be redirected.
        :param pulumi.Input['HttpRedirectTargetArgs'] target: (Updatable) The redirect target object including all the redirect data.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: (Updatable) The user-friendly name of the HTTP Redirect. The name can be changed and does not need to be unique.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        :param pulumi.Input[int] response_code: (Updatable) The response code returned for the redirect to the client. For more information, see [RFC 7231](https://tools.ietf.org/html/rfc7231#section-6.4).
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "domain", domain)
        pulumi.set(__self__, "target", target)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if response_code is not None:
            pulumi.set(__self__, "response_code", response_code)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the HTTP Redirects compartment.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Input[str]:
        """
        The domain from which traffic will be redirected.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: pulumi.Input[str]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter
    def target(self) -> pulumi.Input['HttpRedirectTargetArgs']:
        """
        (Updatable) The redirect target object including all the redirect data.
        """
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: pulumi.Input['HttpRedirectTargetArgs']):
        pulumi.set(self, "target", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The user-friendly name of the HTTP Redirect. The name can be changed and does not need to be unique.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="responseCode")
    def response_code(self) -> Optional[pulumi.Input[int]]:
        """
        (Updatable) The response code returned for the redirect to the client. For more information, see [RFC 7231](https://tools.ietf.org/html/rfc7231#section-6.4).
        """
        return pulumi.get(self, "response_code")

    @response_code.setter
    def response_code(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "response_code", value)


@pulumi.input_type
class _HttpRedirectState:
    def __init__(__self__, *,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 response_code: Optional[pulumi.Input[int]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 target: Optional[pulumi.Input['HttpRedirectTargetArgs']] = None,
                 time_created: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering HttpRedirect resources.
        :param pulumi.Input[str] compartment_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the HTTP Redirects compartment.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: (Updatable) The user-friendly name of the HTTP Redirect. The name can be changed and does not need to be unique.
        :param pulumi.Input[str] domain: The domain from which traffic will be redirected.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        :param pulumi.Input[int] response_code: (Updatable) The response code returned for the redirect to the client. For more information, see [RFC 7231](https://tools.ietf.org/html/rfc7231#section-6.4).
        :param pulumi.Input[str] state: The current lifecycle state of the HTTP Redirect.
        :param pulumi.Input['HttpRedirectTargetArgs'] target: (Updatable) The redirect target object including all the redirect data.
        :param pulumi.Input[str] time_created: The date and time the policy was created, expressed in RFC 3339 timestamp format.
        """
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if domain is not None:
            pulumi.set(__self__, "domain", domain)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if response_code is not None:
            pulumi.set(__self__, "response_code", response_code)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if target is not None:
            pulumi.set(__self__, "target", target)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the HTTP Redirects compartment.
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The user-friendly name of the HTTP Redirect. The name can be changed and does not need to be unique.
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter
    def domain(self) -> Optional[pulumi.Input[str]]:
        """
        The domain from which traffic will be redirected.
        """
        return pulumi.get(self, "domain")

    @domain.setter
    def domain(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "domain", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="responseCode")
    def response_code(self) -> Optional[pulumi.Input[int]]:
        """
        (Updatable) The response code returned for the redirect to the client. For more information, see [RFC 7231](https://tools.ietf.org/html/rfc7231#section-6.4).
        """
        return pulumi.get(self, "response_code")

    @response_code.setter
    def response_code(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "response_code", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current lifecycle state of the HTTP Redirect.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter
    def target(self) -> Optional[pulumi.Input['HttpRedirectTargetArgs']]:
        """
        (Updatable) The redirect target object including all the redirect data.
        """
        return pulumi.get(self, "target")

    @target.setter
    def target(self, value: Optional[pulumi.Input['HttpRedirectTargetArgs']]):
        pulumi.set(self, "target", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The date and time the policy was created, expressed in RFC 3339 timestamp format.
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)


class HttpRedirect(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 response_code: Optional[pulumi.Input[int]] = None,
                 target: Optional[pulumi.Input[pulumi.InputType['HttpRedirectTargetArgs']]] = None,
                 __props__=None):
        """
        This resource provides the Http Redirect resource in Oracle Cloud Infrastructure Web Application Acceleration and Security service.

        Creates a new HTTP Redirect on the WAF edge.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_http_redirect = oci.waas.HttpRedirect("testHttpRedirect",
            compartment_id=var["compartment_id"],
            domain=var["http_redirect_domain"],
            target=oci.waas.HttpRedirectTargetArgs(
                host=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                protocol=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                query=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                port=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            defined_tags={
                "Operations.CostCenter": "42",
            },
            display_name=var["http_redirect_display_name"],
            freeform_tags={
                "Department": "Finance",
            },
            response_code=var["http_redirect_response_code"])
        ```

        ## Import

        HttpRedirects can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Waas/httpRedirect:HttpRedirect test_http_redirect "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the HTTP Redirects compartment.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: (Updatable) The user-friendly name of the HTTP Redirect. The name can be changed and does not need to be unique.
        :param pulumi.Input[str] domain: The domain from which traffic will be redirected.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        :param pulumi.Input[int] response_code: (Updatable) The response code returned for the redirect to the client. For more information, see [RFC 7231](https://tools.ietf.org/html/rfc7231#section-6.4).
        :param pulumi.Input[pulumi.InputType['HttpRedirectTargetArgs']] target: (Updatable) The redirect target object including all the redirect data.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: HttpRedirectArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Http Redirect resource in Oracle Cloud Infrastructure Web Application Acceleration and Security service.

        Creates a new HTTP Redirect on the WAF edge.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_http_redirect = oci.waas.HttpRedirect("testHttpRedirect",
            compartment_id=var["compartment_id"],
            domain=var["http_redirect_domain"],
            target=oci.waas.HttpRedirectTargetArgs(
                host=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                protocol=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                query=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                port=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            defined_tags={
                "Operations.CostCenter": "42",
            },
            display_name=var["http_redirect_display_name"],
            freeform_tags={
                "Department": "Finance",
            },
            response_code=var["http_redirect_response_code"])
        ```

        ## Import

        HttpRedirects can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:Waas/httpRedirect:HttpRedirect test_http_redirect "id"
        ```

        :param str resource_name: The name of the resource.
        :param HttpRedirectArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(HttpRedirectArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 domain: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 response_code: Optional[pulumi.Input[int]] = None,
                 target: Optional[pulumi.Input[pulumi.InputType['HttpRedirectTargetArgs']]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = HttpRedirectArgs.__new__(HttpRedirectArgs)

            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["defined_tags"] = defined_tags
            __props__.__dict__["display_name"] = display_name
            if domain is None and not opts.urn:
                raise TypeError("Missing required property 'domain'")
            __props__.__dict__["domain"] = domain
            __props__.__dict__["freeform_tags"] = freeform_tags
            __props__.__dict__["response_code"] = response_code
            if target is None and not opts.urn:
                raise TypeError("Missing required property 'target'")
            __props__.__dict__["target"] = target
            __props__.__dict__["state"] = None
            __props__.__dict__["time_created"] = None
        super(HttpRedirect, __self__).__init__(
            'oci:Waas/httpRedirect:HttpRedirect',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            domain: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            response_code: Optional[pulumi.Input[int]] = None,
            state: Optional[pulumi.Input[str]] = None,
            target: Optional[pulumi.Input[pulumi.InputType['HttpRedirectTargetArgs']]] = None,
            time_created: Optional[pulumi.Input[str]] = None) -> 'HttpRedirect':
        """
        Get an existing HttpRedirect resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] compartment_id: (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the HTTP Redirects compartment.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[str] display_name: (Updatable) The user-friendly name of the HTTP Redirect. The name can be changed and does not need to be unique.
        :param pulumi.Input[str] domain: The domain from which traffic will be redirected.
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        :param pulumi.Input[int] response_code: (Updatable) The response code returned for the redirect to the client. For more information, see [RFC 7231](https://tools.ietf.org/html/rfc7231#section-6.4).
        :param pulumi.Input[str] state: The current lifecycle state of the HTTP Redirect.
        :param pulumi.Input[pulumi.InputType['HttpRedirectTargetArgs']] target: (Updatable) The redirect target object including all the redirect data.
        :param pulumi.Input[str] time_created: The date and time the policy was created, expressed in RFC 3339 timestamp format.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _HttpRedirectState.__new__(_HttpRedirectState)

        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["domain"] = domain
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["response_code"] = response_code
        __props__.__dict__["state"] = state
        __props__.__dict__["target"] = target
        __props__.__dict__["time_created"] = time_created
        return HttpRedirect(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        (Updatable) The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the HTTP Redirects compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        (Updatable) The user-friendly name of the HTTP Redirect. The name can be changed and does not need to be unique.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def domain(self) -> pulumi.Output[str]:
        """
        The domain from which traffic will be redirected.
        """
        return pulumi.get(self, "domain")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="responseCode")
    def response_code(self) -> pulumi.Output[int]:
        """
        (Updatable) The response code returned for the redirect to the client. For more information, see [RFC 7231](https://tools.ietf.org/html/rfc7231#section-6.4).
        """
        return pulumi.get(self, "response_code")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current lifecycle state of the HTTP Redirect.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def target(self) -> pulumi.Output['outputs.HttpRedirectTarget']:
        """
        (Updatable) The redirect target object including all the redirect data.
        """
        return pulumi.get(self, "target")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The date and time the policy was created, expressed in RFC 3339 timestamp format.
        """
        return pulumi.get(self, "time_created")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetEventsAuditEventResult',
    'GetEventsAuditEventDataResult',
    'GetEventsAuditEventDataIdentityResult',
    'GetEventsAuditEventDataRequestResult',
    'GetEventsAuditEventDataResponseResult',
    'GetEventsAuditEventDataStateChangeResult',
    'GetEventsFilterResult',
]

@pulumi.output_type
class GetEventsAuditEventResult(dict):
    def __init__(__self__, *,
                 cloud_events_version: str,
                 content_type: str,
                 datas: Sequence['outputs.GetEventsAuditEventDataResult'],
                 event_id: str,
                 event_time: str,
                 event_type: str,
                 event_type_version: str,
                 source: str):
        """
        :param str cloud_events_version: The version of the CloudEvents specification. The structure of the envelope follows the  [CloudEvents](https://github.com/cloudevents/spec) industry standard format hosted by the [Cloud Native Computing Foundation ( CNCF)](https://www.cncf.io/).
        :param str content_type: The content type of the data contained in `data`.  Example: `application/json`
        :param Sequence['GetEventsAuditEventDataArgs'] datas: The payload of the event. Information within `data` comes from the resource emitting the event.
        :param str event_id: The GUID of the event.
        :param str event_time: The time the event occurred, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.  Example: `2019-09-18T00:10:59.252Z`
        :param str event_type: The type of event that happened.
        :param str event_type_version: The version of the event type. This version applies to the payload of the event, not the envelope. Use `cloudEventsVersion` to determine the version of the envelope.  Example: `2.0`
        :param str source: The source of the event.  Example: `ComputeApi`
        """
        pulumi.set(__self__, "cloud_events_version", cloud_events_version)
        pulumi.set(__self__, "content_type", content_type)
        pulumi.set(__self__, "datas", datas)
        pulumi.set(__self__, "event_id", event_id)
        pulumi.set(__self__, "event_time", event_time)
        pulumi.set(__self__, "event_type", event_type)
        pulumi.set(__self__, "event_type_version", event_type_version)
        pulumi.set(__self__, "source", source)

    @property
    @pulumi.getter(name="cloudEventsVersion")
    def cloud_events_version(self) -> str:
        """
        The version of the CloudEvents specification. The structure of the envelope follows the  [CloudEvents](https://github.com/cloudevents/spec) industry standard format hosted by the [Cloud Native Computing Foundation ( CNCF)](https://www.cncf.io/).
        """
        return pulumi.get(self, "cloud_events_version")

    @property
    @pulumi.getter(name="contentType")
    def content_type(self) -> str:
        """
        The content type of the data contained in `data`.  Example: `application/json`
        """
        return pulumi.get(self, "content_type")

    @property
    @pulumi.getter
    def datas(self) -> Sequence['outputs.GetEventsAuditEventDataResult']:
        """
        The payload of the event. Information within `data` comes from the resource emitting the event.
        """
        return pulumi.get(self, "datas")

    @property
    @pulumi.getter(name="eventId")
    def event_id(self) -> str:
        """
        The GUID of the event.
        """
        return pulumi.get(self, "event_id")

    @property
    @pulumi.getter(name="eventTime")
    def event_time(self) -> str:
        """
        The time the event occurred, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.  Example: `2019-09-18T00:10:59.252Z`
        """
        return pulumi.get(self, "event_time")

    @property
    @pulumi.getter(name="eventType")
    def event_type(self) -> str:
        """
        The type of event that happened.
        """
        return pulumi.get(self, "event_type")

    @property
    @pulumi.getter(name="eventTypeVersion")
    def event_type_version(self) -> str:
        """
        The version of the event type. This version applies to the payload of the event, not the envelope. Use `cloudEventsVersion` to determine the version of the envelope.  Example: `2.0`
        """
        return pulumi.get(self, "event_type_version")

    @property
    @pulumi.getter
    def source(self) -> str:
        """
        The source of the event.  Example: `ComputeApi`
        """
        return pulumi.get(self, "source")


@pulumi.output_type
class GetEventsAuditEventDataResult(dict):
    def __init__(__self__, *,
                 additional_details: Mapping[str, Any],
                 availability_domain: str,
                 compartment_id: str,
                 compartment_name: str,
                 defined_tags: Mapping[str, Any],
                 event_grouping_id: str,
                 event_name: str,
                 freeform_tags: Mapping[str, Any],
                 identities: Sequence['outputs.GetEventsAuditEventDataIdentityResult'],
                 requests: Sequence['outputs.GetEventsAuditEventDataRequestResult'],
                 resource_id: str,
                 resource_name: str,
                 responses: Sequence['outputs.GetEventsAuditEventDataResponseResult'],
                 state_changes: Sequence['outputs.GetEventsAuditEventDataStateChangeResult']):
        """
        :param Mapping[str, Any] additional_details: A container object for attribues unique to the resource emitting the event.
        :param str availability_domain: The availability domain where the resource resides.
        :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        :param str compartment_name: The name of the compartment. This value is the friendly name associated with compartmentId. This value can change, but the service logs the value that appeared at the time of the audit event.  Example: `CompartmentA`
        :param Mapping[str, Any] defined_tags: Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        :param str event_grouping_id: This value links multiple audit events that are part of the same API operation. For example,  a long running API operations that emit an event at the start and the end of an operation would use the same value in this field for both events.
        :param str event_name: Name of the API operation that generated this event.  Example: `GetInstance`
        :param Mapping[str, Any] freeform_tags: Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name,  type, or namespace. Exists for cross-compatibility only. For more information,  see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        :param Sequence['GetEventsAuditEventDataIdentityArgs'] identities: A container object for identity attributes.
        :param Sequence['GetEventsAuditEventDataRequestArgs'] requests: A container object for request attributes.
        :param str resource_id: An [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) or some other ID for the resource emitting the event.
        :param str resource_name: The name of the resource emitting the event.
        :param Sequence['GetEventsAuditEventDataResponseArgs'] responses: A container object for response attributes.
        :param Sequence['GetEventsAuditEventDataStateChangeArgs'] state_changes: A container object for state change attributes.
        """
        pulumi.set(__self__, "additional_details", additional_details)
        pulumi.set(__self__, "availability_domain", availability_domain)
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "compartment_name", compartment_name)
        pulumi.set(__self__, "defined_tags", defined_tags)
        pulumi.set(__self__, "event_grouping_id", event_grouping_id)
        pulumi.set(__self__, "event_name", event_name)
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        pulumi.set(__self__, "identities", identities)
        pulumi.set(__self__, "requests", requests)
        pulumi.set(__self__, "resource_id", resource_id)
        pulumi.set(__self__, "resource_name", resource_name)
        pulumi.set(__self__, "responses", responses)
        pulumi.set(__self__, "state_changes", state_changes)

    @property
    @pulumi.getter(name="additionalDetails")
    def additional_details(self) -> Mapping[str, Any]:
        """
        A container object for attribues unique to the resource emitting the event.
        """
        return pulumi.get(self, "additional_details")

    @property
    @pulumi.getter(name="availabilityDomain")
    def availability_domain(self) -> str:
        """
        The availability domain where the resource resides.
        """
        return pulumi.get(self, "availability_domain")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="compartmentName")
    def compartment_name(self) -> str:
        """
        The name of the compartment. This value is the friendly name associated with compartmentId. This value can change, but the service logs the value that appeared at the time of the audit event.  Example: `CompartmentA`
        """
        return pulumi.get(self, "compartment_name")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="eventGroupingId")
    def event_grouping_id(self) -> str:
        """
        This value links multiple audit events that are part of the same API operation. For example,  a long running API operations that emit an event at the start and the end of an operation would use the same value in this field for both events.
        """
        return pulumi.get(self, "event_grouping_id")

    @property
    @pulumi.getter(name="eventName")
    def event_name(self) -> str:
        """
        Name of the API operation that generated this event.  Example: `GetInstance`
        """
        return pulumi.get(self, "event_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name,  type, or namespace. Exists for cross-compatibility only. For more information,  see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).  Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def identities(self) -> Sequence['outputs.GetEventsAuditEventDataIdentityResult']:
        """
        A container object for identity attributes.
        """
        return pulumi.get(self, "identities")

    @property
    @pulumi.getter
    def requests(self) -> Sequence['outputs.GetEventsAuditEventDataRequestResult']:
        """
        A container object for request attributes.
        """
        return pulumi.get(self, "requests")

    @property
    @pulumi.getter(name="resourceId")
    def resource_id(self) -> str:
        """
        An [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) or some other ID for the resource emitting the event.
        """
        return pulumi.get(self, "resource_id")

    @property
    @pulumi.getter(name="resourceName")
    def resource_name(self) -> str:
        """
        The name of the resource emitting the event.
        """
        return pulumi.get(self, "resource_name")

    @property
    @pulumi.getter
    def responses(self) -> Sequence['outputs.GetEventsAuditEventDataResponseResult']:
        """
        A container object for response attributes.
        """
        return pulumi.get(self, "responses")

    @property
    @pulumi.getter(name="stateChanges")
    def state_changes(self) -> Sequence['outputs.GetEventsAuditEventDataStateChangeResult']:
        """
        A container object for state change attributes.
        """
        return pulumi.get(self, "state_changes")


@pulumi.output_type
class GetEventsAuditEventDataIdentityResult(dict):
    def __init__(__self__, *,
                 auth_type: str,
                 caller_id: str,
                 caller_name: str,
                 console_session_id: str,
                 credentials: str,
                 ip_address: str,
                 principal_id: str,
                 principal_name: str,
                 tenant_id: str,
                 user_agent: str):
        """
        :param str auth_type: The type of authentication used.  Example: `natv`
        :param str caller_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the caller. The caller that made a  request on behalf of the prinicpal.
        :param str caller_name: The name of the user or service. This value is the friendly name associated with `callerId`.
        :param str console_session_id: This value identifies any Console session associated with this request.
        :param str credentials: The credential ID of the user. This value is extracted from the HTTP 'Authorization' request header. It consists of the tenantId, userId, and user fingerprint, all delimited by a slash (/).
        :param str ip_address: The IP address of the source of the request.  Example: `172.24.80.88`
        :param str principal_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the principal.
        :param str principal_name: The name of the user or service. This value is the friendly name associated with `principalId`.  Example: `ExampleName`
        :param str tenant_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the tenant.
        :param str user_agent: The user agent of the client that made the request.  Example: `Jersey/2.23 (HttpUrlConnection 1.8.0_212)`
        """
        pulumi.set(__self__, "auth_type", auth_type)
        pulumi.set(__self__, "caller_id", caller_id)
        pulumi.set(__self__, "caller_name", caller_name)
        pulumi.set(__self__, "console_session_id", console_session_id)
        pulumi.set(__self__, "credentials", credentials)
        pulumi.set(__self__, "ip_address", ip_address)
        pulumi.set(__self__, "principal_id", principal_id)
        pulumi.set(__self__, "principal_name", principal_name)
        pulumi.set(__self__, "tenant_id", tenant_id)
        pulumi.set(__self__, "user_agent", user_agent)

    @property
    @pulumi.getter(name="authType")
    def auth_type(self) -> str:
        """
        The type of authentication used.  Example: `natv`
        """
        return pulumi.get(self, "auth_type")

    @property
    @pulumi.getter(name="callerId")
    def caller_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the caller. The caller that made a  request on behalf of the prinicpal.
        """
        return pulumi.get(self, "caller_id")

    @property
    @pulumi.getter(name="callerName")
    def caller_name(self) -> str:
        """
        The name of the user or service. This value is the friendly name associated with `callerId`.
        """
        return pulumi.get(self, "caller_name")

    @property
    @pulumi.getter(name="consoleSessionId")
    def console_session_id(self) -> str:
        """
        This value identifies any Console session associated with this request.
        """
        return pulumi.get(self, "console_session_id")

    @property
    @pulumi.getter
    def credentials(self) -> str:
        """
        The credential ID of the user. This value is extracted from the HTTP 'Authorization' request header. It consists of the tenantId, userId, and user fingerprint, all delimited by a slash (/).
        """
        return pulumi.get(self, "credentials")

    @property
    @pulumi.getter(name="ipAddress")
    def ip_address(self) -> str:
        """
        The IP address of the source of the request.  Example: `172.24.80.88`
        """
        return pulumi.get(self, "ip_address")

    @property
    @pulumi.getter(name="principalId")
    def principal_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the principal.
        """
        return pulumi.get(self, "principal_id")

    @property
    @pulumi.getter(name="principalName")
    def principal_name(self) -> str:
        """
        The name of the user or service. This value is the friendly name associated with `principalId`.  Example: `ExampleName`
        """
        return pulumi.get(self, "principal_name")

    @property
    @pulumi.getter(name="tenantId")
    def tenant_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the tenant.
        """
        return pulumi.get(self, "tenant_id")

    @property
    @pulumi.getter(name="userAgent")
    def user_agent(self) -> str:
        """
        The user agent of the client that made the request.  Example: `Jersey/2.23 (HttpUrlConnection 1.8.0_212)`
        """
        return pulumi.get(self, "user_agent")


@pulumi.output_type
class GetEventsAuditEventDataRequestResult(dict):
    def __init__(__self__, *,
                 action: str,
                 headers: Mapping[str, Any],
                 id: str,
                 parameters: Mapping[str, Any],
                 path: str):
        """
        :param str action: The HTTP method of the request.  Example: `GET`
        :param Mapping[str, Any] headers: The headers of the response.
        :param str id: The opc-request-id of the request.
        :param Mapping[str, Any] parameters: The parameters supplied by the caller during this operation.
        :param str path: The full path of the API request.  Example: `/20160918/instances/ocid1.instance.oc1.phx.<unique_ID>`
        """
        pulumi.set(__self__, "action", action)
        pulumi.set(__self__, "headers", headers)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "parameters", parameters)
        pulumi.set(__self__, "path", path)

    @property
    @pulumi.getter
    def action(self) -> str:
        """
        The HTTP method of the request.  Example: `GET`
        """
        return pulumi.get(self, "action")

    @property
    @pulumi.getter
    def headers(self) -> Mapping[str, Any]:
        """
        The headers of the response.
        """
        return pulumi.get(self, "headers")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The opc-request-id of the request.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def parameters(self) -> Mapping[str, Any]:
        """
        The parameters supplied by the caller during this operation.
        """
        return pulumi.get(self, "parameters")

    @property
    @pulumi.getter
    def path(self) -> str:
        """
        The full path of the API request.  Example: `/20160918/instances/ocid1.instance.oc1.phx.<unique_ID>`
        """
        return pulumi.get(self, "path")


@pulumi.output_type
class GetEventsAuditEventDataResponseResult(dict):
    def __init__(__self__, *,
                 headers: Mapping[str, Any],
                 message: str,
                 payload: Mapping[str, Any],
                 response_time: str,
                 status: str):
        """
        :param Mapping[str, Any] headers: The headers of the response.
        :param str message: A friendly description of what happened during the operation. Use this for troubleshooting.
        :param Mapping[str, Any] payload: This value is included for backward compatibility with the Audit version 1 schema, where  it contained metadata of interest from the response payload.
        :param str response_time: The time of the response to the audited request, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.  Example: `2019-09-18T00:10:59.278Z`
        :param str status: The status code of the response.  Example: `200`
        """
        pulumi.set(__self__, "headers", headers)
        pulumi.set(__self__, "message", message)
        pulumi.set(__self__, "payload", payload)
        pulumi.set(__self__, "response_time", response_time)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def headers(self) -> Mapping[str, Any]:
        """
        The headers of the response.
        """
        return pulumi.get(self, "headers")

    @property
    @pulumi.getter
    def message(self) -> str:
        """
        A friendly description of what happened during the operation. Use this for troubleshooting.
        """
        return pulumi.get(self, "message")

    @property
    @pulumi.getter
    def payload(self) -> Mapping[str, Any]:
        """
        This value is included for backward compatibility with the Audit version 1 schema, where  it contained metadata of interest from the response payload.
        """
        return pulumi.get(self, "payload")

    @property
    @pulumi.getter(name="responseTime")
    def response_time(self) -> str:
        """
        The time of the response to the audited request, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.  Example: `2019-09-18T00:10:59.278Z`
        """
        return pulumi.get(self, "response_time")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status code of the response.  Example: `200`
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetEventsAuditEventDataStateChangeResult(dict):
    def __init__(__self__, *,
                 current: Mapping[str, Any],
                 previous: Mapping[str, Any]):
        """
        :param Mapping[str, Any] current: Provides the current state of fields that may have changed during an operation. To determine how the current operation changed a resource, compare the information in this attribute to  `previous`.
        :param Mapping[str, Any] previous: Provides the previous state of fields that may have changed during an operation. To determine how the current operation changed a resource, compare the information in this attribute to  `current`.
        """
        pulumi.set(__self__, "current", current)
        pulumi.set(__self__, "previous", previous)

    @property
    @pulumi.getter
    def current(self) -> Mapping[str, Any]:
        """
        Provides the current state of fields that may have changed during an operation. To determine how the current operation changed a resource, compare the information in this attribute to  `previous`.
        """
        return pulumi.get(self, "current")

    @property
    @pulumi.getter
    def previous(self) -> Mapping[str, Any]:
        """
        Provides the previous state of fields that may have changed during an operation. To determine how the current operation changed a resource, compare the information in this attribute to  `current`.
        """
        return pulumi.get(self, "previous")


@pulumi.output_type
class GetEventsFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetInstVbsInstancesFilterResult',
    'GetInstVbsInstancesVbsInstanceSummaryCollectionResult',
    'GetInstVbsInstancesVbsInstanceSummaryCollectionItemResult',
]

@pulumi.output_type
class GetInstVbsInstancesFilterResult(dict):
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        """
        :param str name: A filter to return only resources that match the entire name given.
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A filter to return only resources that match the entire name given.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")


@pulumi.output_type
class GetInstVbsInstancesVbsInstanceSummaryCollectionResult(dict):
    def __init__(__self__, *,
                 items: Sequence['outputs.GetInstVbsInstancesVbsInstanceSummaryCollectionItemResult']):
        pulumi.set(__self__, "items", items)

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetInstVbsInstancesVbsInstanceSummaryCollectionItemResult']:
        return pulumi.get(self, "items")


@pulumi.output_type
class GetInstVbsInstancesVbsInstanceSummaryCollectionItemResult(dict):
    def __init__(__self__, *,
                 compartment_id: str,
                 defined_tags: Mapping[str, Any],
                 display_name: str,
                 freeform_tags: Mapping[str, Any],
                 id: str,
                 idcs_access_token: str,
                 is_resource_usage_agreement_granted: bool,
                 lifecyle_details: str,
                 name: str,
                 resource_compartment_id: str,
                 state: str,
                 system_tags: Mapping[str, Any],
                 time_created: str,
                 time_updated: str,
                 vbs_access_url: str):
        """
        :param str compartment_id: The ID of the compartment in which to list resources.
        :param Mapping[str, Any] defined_tags: Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        :param str display_name: Service instance display name
        :param Mapping[str, Any] freeform_tags: Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        :param str id: unique VbsInstance identifier
        :param bool is_resource_usage_agreement_granted: Whether the VBS service instance owner explicitly approved VBS to create and use resources in the customer tenancy
        :param str lifecyle_details: A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        :param str name: A filter to return only resources that match the entire name given.
        :param str resource_compartment_id: Compartment where VBS may create additional resources for the service instance
        :param str state: A filter to return only resources their lifecycleState matches the given lifecycleState.
        :param Mapping[str, Any] system_tags: Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        :param str time_created: The time the the VbsInstance was created. An RFC3339 formatted datetime string
        :param str time_updated: The time the VbsInstance was updated. An RFC3339 formatted datetime string
        :param str vbs_access_url: Public web URL for accessing the VBS service instance
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "defined_tags", defined_tags)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "freeform_tags", freeform_tags)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "idcs_access_token", idcs_access_token)
        pulumi.set(__self__, "is_resource_usage_agreement_granted", is_resource_usage_agreement_granted)
        pulumi.set(__self__, "lifecyle_details", lifecyle_details)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "resource_compartment_id", resource_compartment_id)
        pulumi.set(__self__, "state", state)
        pulumi.set(__self__, "system_tags", system_tags)
        pulumi.set(__self__, "time_created", time_created)
        pulumi.set(__self__, "time_updated", time_updated)
        pulumi.set(__self__, "vbs_access_url", vbs_access_url)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The ID of the compartment in which to list resources.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Mapping[str, Any]:
        """
        Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"foo-namespace.bar-key": "value"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        Service instance display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Mapping[str, Any]:
        """
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"bar-key": "value"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        unique VbsInstance identifier
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="idcsAccessToken")
    def idcs_access_token(self) -> str:
        return pulumi.get(self, "idcs_access_token")

    @property
    @pulumi.getter(name="isResourceUsageAgreementGranted")
    def is_resource_usage_agreement_granted(self) -> bool:
        """
        Whether the VBS service instance owner explicitly approved VBS to create and use resources in the customer tenancy
        """
        return pulumi.get(self, "is_resource_usage_agreement_granted")

    @property
    @pulumi.getter(name="lifecyleDetails")
    def lifecyle_details(self) -> str:
        """
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.
        """
        return pulumi.get(self, "lifecyle_details")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        A filter to return only resources that match the entire name given.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="resourceCompartmentId")
    def resource_compartment_id(self) -> str:
        """
        Compartment where VBS may create additional resources for the service instance
        """
        return pulumi.get(self, "resource_compartment_id")

    @property
    @pulumi.getter
    def state(self) -> str:
        """
        A filter to return only resources their lifecycleState matches the given lifecycleState.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Mapping[str, Any]:
        """
        Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The time the the VbsInstance was created. An RFC3339 formatted datetime string
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> str:
        """
        The time the VbsInstance was updated. An RFC3339 formatted datetime string
        """
        return pulumi.get(self, "time_updated")

    @property
    @pulumi.getter(name="vbsAccessUrl")
    def vbs_access_url(self) -> str:
        """
        Public web URL for accessing the VBS service instance
        """
        return pulumi.get(self, "vbs_access_url")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetPrivateApplicationPackageResult',
    'AwaitableGetPrivateApplicationPackageResult',
    'get_private_application_package',
    'get_private_application_package_output',
]

@pulumi.output_type
class GetPrivateApplicationPackageResult:
    """
    A collection of values returned by getPrivateApplicationPackage.
    """
    def __init__(__self__, content_url=None, display_name=None, id=None, mime_type=None, package_type=None, private_application_id=None, private_application_package_id=None, time_created=None, version=None):
        if content_url and not isinstance(content_url, str):
            raise TypeError("Expected argument 'content_url' to be a str")
        pulumi.set(__self__, "content_url", content_url)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if mime_type and not isinstance(mime_type, str):
            raise TypeError("Expected argument 'mime_type' to be a str")
        pulumi.set(__self__, "mime_type", mime_type)
        if package_type and not isinstance(package_type, str):
            raise TypeError("Expected argument 'package_type' to be a str")
        pulumi.set(__self__, "package_type", package_type)
        if private_application_id and not isinstance(private_application_id, str):
            raise TypeError("Expected argument 'private_application_id' to be a str")
        pulumi.set(__self__, "private_application_id", private_application_id)
        if private_application_package_id and not isinstance(private_application_package_id, str):
            raise TypeError("Expected argument 'private_application_package_id' to be a str")
        pulumi.set(__self__, "private_application_package_id", private_application_package_id)
        if time_created and not isinstance(time_created, str):
            raise TypeError("Expected argument 'time_created' to be a str")
        pulumi.set(__self__, "time_created", time_created)
        if version and not isinstance(version, str):
            raise TypeError("Expected argument 'version' to be a str")
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="contentUrl")
    def content_url(self) -> str:
        return pulumi.get(self, "content_url")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        The display name of the package.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="mimeType")
    def mime_type(self) -> str:
        return pulumi.get(self, "mime_type")

    @property
    @pulumi.getter(name="packageType")
    def package_type(self) -> str:
        """
        The specified package's type.
        """
        return pulumi.get(self, "package_type")

    @property
    @pulumi.getter(name="privateApplicationId")
    def private_application_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the private application where the package is hosted.
        """
        return pulumi.get(self, "private_application_id")

    @property
    @pulumi.getter(name="privateApplicationPackageId")
    def private_application_package_id(self) -> str:
        return pulumi.get(self, "private_application_package_id")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> str:
        """
        The date and time the private application package was created, expressed in [RFC 3339](https://tools.ietf.org/html/rfc3339) timestamp format.  Example: `2021-05-27T21:10:29.600Z`
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter
    def version(self) -> str:
        """
        The package version.
        """
        return pulumi.get(self, "version")


class AwaitableGetPrivateApplicationPackageResult(GetPrivateApplicationPackageResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPrivateApplicationPackageResult(
            content_url=self.content_url,
            display_name=self.display_name,
            id=self.id,
            mime_type=self.mime_type,
            package_type=self.package_type,
            private_application_id=self.private_application_id,
            private_application_package_id=self.private_application_package_id,
            time_created=self.time_created,
            version=self.version)


def get_private_application_package(private_application_package_id: Optional[str] = None,
                                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPrivateApplicationPackageResult:
    """
    This data source provides details about a specific Private Application Package resource in Oracle Cloud Infrastructure Service Catalog service.

    Gets the details of a specific package within a given private application.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_private_application_package = oci.ServiceCatalog.get_private_application_package(private_application_package_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str private_application_package_id: The unique identifier for the private application package.
    """
    __args__ = dict()
    __args__['privateApplicationPackageId'] = private_application_package_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:ServiceCatalog/getPrivateApplicationPackage:getPrivateApplicationPackage', __args__, opts=opts, typ=GetPrivateApplicationPackageResult).value

    return AwaitableGetPrivateApplicationPackageResult(
        content_url=__ret__.content_url,
        display_name=__ret__.display_name,
        id=__ret__.id,
        mime_type=__ret__.mime_type,
        package_type=__ret__.package_type,
        private_application_id=__ret__.private_application_id,
        private_application_package_id=__ret__.private_application_package_id,
        time_created=__ret__.time_created,
        version=__ret__.version)


@_utilities.lift_output_func(get_private_application_package)
def get_private_application_package_output(private_application_package_id: Optional[pulumi.Input[str]] = None,
                                           opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetPrivateApplicationPackageResult]:
    """
    This data source provides details about a specific Private Application Package resource in Oracle Cloud Infrastructure Service Catalog service.

    Gets the details of a specific package within a given private application.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_private_application_package = oci.ServiceCatalog.get_private_application_package(private_application_package_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str private_application_package_id: The unique identifier for the private application package.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs

__all__ = [
    'GetMaskingReportsMaskedColumnResult',
    'AwaitableGetMaskingReportsMaskedColumnResult',
    'get_masking_reports_masked_column',
    'get_masking_reports_masked_column_output',
]

@pulumi.output_type
class GetMaskingReportsMaskedColumnResult:
    """
    A collection of values returned by getMaskingReportsMaskedColumn.
    """
    def __init__(__self__, column_names=None, id=None, items=None, masking_column_groups=None, masking_report_id=None, object_types=None, objects=None, schema_names=None, sensitive_type_id=None):
        if column_names and not isinstance(column_names, list):
            raise TypeError("Expected argument 'column_names' to be a list")
        pulumi.set(__self__, "column_names", column_names)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if items and not isinstance(items, list):
            raise TypeError("Expected argument 'items' to be a list")
        pulumi.set(__self__, "items", items)
        if masking_column_groups and not isinstance(masking_column_groups, list):
            raise TypeError("Expected argument 'masking_column_groups' to be a list")
        pulumi.set(__self__, "masking_column_groups", masking_column_groups)
        if masking_report_id and not isinstance(masking_report_id, str):
            raise TypeError("Expected argument 'masking_report_id' to be a str")
        pulumi.set(__self__, "masking_report_id", masking_report_id)
        if object_types and not isinstance(object_types, list):
            raise TypeError("Expected argument 'object_types' to be a list")
        pulumi.set(__self__, "object_types", object_types)
        if objects and not isinstance(objects, list):
            raise TypeError("Expected argument 'objects' to be a list")
        pulumi.set(__self__, "objects", objects)
        if schema_names and not isinstance(schema_names, list):
            raise TypeError("Expected argument 'schema_names' to be a list")
        pulumi.set(__self__, "schema_names", schema_names)
        if sensitive_type_id and not isinstance(sensitive_type_id, str):
            raise TypeError("Expected argument 'sensitive_type_id' to be a str")
        pulumi.set(__self__, "sensitive_type_id", sensitive_type_id)

    @property
    @pulumi.getter(name="columnNames")
    def column_names(self) -> Optional[Sequence[str]]:
        """
        The name of the masked column.
        """
        return pulumi.get(self, "column_names")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def items(self) -> Sequence['outputs.GetMaskingReportsMaskedColumnItemResult']:
        """
        An array of masking column summary objects.
        """
        return pulumi.get(self, "items")

    @property
    @pulumi.getter(name="maskingColumnGroups")
    def masking_column_groups(self) -> Optional[Sequence[str]]:
        """
        The masking group of the masked column.
        """
        return pulumi.get(self, "masking_column_groups")

    @property
    @pulumi.getter(name="maskingReportId")
    def masking_report_id(self) -> str:
        return pulumi.get(self, "masking_report_id")

    @property
    @pulumi.getter(name="objectTypes")
    def object_types(self) -> Optional[Sequence[str]]:
        """
        The type of the object (table or editioning view) that contains the masked column.
        """
        return pulumi.get(self, "object_types")

    @property
    @pulumi.getter
    def objects(self) -> Optional[Sequence[str]]:
        """
        The name of the object (table or editioning view) that contains the masked column.
        """
        return pulumi.get(self, "objects")

    @property
    @pulumi.getter(name="schemaNames")
    def schema_names(self) -> Optional[Sequence[str]]:
        """
        The name of the schema that contains the masked column.
        """
        return pulumi.get(self, "schema_names")

    @property
    @pulumi.getter(name="sensitiveTypeId")
    def sensitive_type_id(self) -> Optional[str]:
        """
        The OCID of the sensitive type associated with the masked column.
        """
        return pulumi.get(self, "sensitive_type_id")


class AwaitableGetMaskingReportsMaskedColumnResult(GetMaskingReportsMaskedColumnResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetMaskingReportsMaskedColumnResult(
            column_names=self.column_names,
            id=self.id,
            items=self.items,
            masking_column_groups=self.masking_column_groups,
            masking_report_id=self.masking_report_id,
            object_types=self.object_types,
            objects=self.objects,
            schema_names=self.schema_names,
            sensitive_type_id=self.sensitive_type_id)


def get_masking_reports_masked_column(column_names: Optional[Sequence[str]] = None,
                                      masking_column_groups: Optional[Sequence[str]] = None,
                                      masking_report_id: Optional[str] = None,
                                      object_types: Optional[Sequence[str]] = None,
                                      objects: Optional[Sequence[str]] = None,
                                      schema_names: Optional[Sequence[str]] = None,
                                      sensitive_type_id: Optional[str] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetMaskingReportsMaskedColumnResult:
    """
    This data source provides details about a specific Masking Reports Masked Column resource in Oracle Cloud Infrastructure Data Safe service.

    Gets a list of masked columns present in the specified masking report and based on the specified query parameters.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_masking_reports_masked_column = oci.DataSafe.get_masking_reports_masked_column(masking_report_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        column_names=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        masking_column_groups=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        objects=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        object_types=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        schema_names=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        sensitive_type_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param Sequence[str] column_names: A filter to return only a specific column based on column name.
    :param Sequence[str] masking_column_groups: A filter to return only the resources that match the specified masking column group.
    :param str masking_report_id: The OCID of the masking report.
    :param Sequence[str] object_types: A filter to return only items related to a specific object type.
    :param Sequence[str] objects: A filter to return only items related to a specific object name.
    :param Sequence[str] schema_names: A filter to return only items related to specific schema name.
    :param str sensitive_type_id: A filter to return only items related to a specific sensitive type OCID.
    """
    __args__ = dict()
    __args__['columnNames'] = column_names
    __args__['maskingColumnGroups'] = masking_column_groups
    __args__['maskingReportId'] = masking_report_id
    __args__['objectTypes'] = object_types
    __args__['objects'] = objects
    __args__['schemaNames'] = schema_names
    __args__['sensitiveTypeId'] = sensitive_type_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:DataSafe/getMaskingReportsMaskedColumn:getMaskingReportsMaskedColumn', __args__, opts=opts, typ=GetMaskingReportsMaskedColumnResult).value

    return AwaitableGetMaskingReportsMaskedColumnResult(
        column_names=__ret__.column_names,
        id=__ret__.id,
        items=__ret__.items,
        masking_column_groups=__ret__.masking_column_groups,
        masking_report_id=__ret__.masking_report_id,
        object_types=__ret__.object_types,
        objects=__ret__.objects,
        schema_names=__ret__.schema_names,
        sensitive_type_id=__ret__.sensitive_type_id)


@_utilities.lift_output_func(get_masking_reports_masked_column)
def get_masking_reports_masked_column_output(column_names: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                             masking_column_groups: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                             masking_report_id: Optional[pulumi.Input[str]] = None,
                                             object_types: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                             objects: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                             schema_names: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                             sensitive_type_id: Optional[pulumi.Input[Optional[str]]] = None,
                                             opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetMaskingReportsMaskedColumnResult]:
    """
    This data source provides details about a specific Masking Reports Masked Column resource in Oracle Cloud Infrastructure Data Safe service.

    Gets a list of masked columns present in the specified masking report and based on the specified query parameters.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_masking_reports_masked_column = oci.DataSafe.get_masking_reports_masked_column(masking_report_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        column_names=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        masking_column_groups=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        objects=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        object_types=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        schema_names=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        sensitive_type_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param Sequence[str] column_names: A filter to return only a specific column based on column name.
    :param Sequence[str] masking_column_groups: A filter to return only the resources that match the specified masking column group.
    :param str masking_report_id: The OCID of the masking report.
    :param Sequence[str] object_types: A filter to return only items related to a specific object type.
    :param Sequence[str] objects: A filter to return only items related to a specific object name.
    :param Sequence[str] schema_names: A filter to return only items related to specific schema name.
    :param str sensitive_type_id: A filter to return only items related to a specific sensitive type OCID.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetByoipAllocatedRangesResult',
    'AwaitableGetByoipAllocatedRangesResult',
    'get_byoip_allocated_ranges',
    'get_byoip_allocated_ranges_output',
]

@pulumi.output_type
class GetByoipAllocatedRangesResult:
    """
    A collection of values returned by getByoipAllocatedRanges.
    """
    def __init__(__self__, byoip_allocated_range_collections=None, byoip_range_id=None, filters=None, id=None):
        if byoip_allocated_range_collections and not isinstance(byoip_allocated_range_collections, list):
            raise TypeError("Expected argument 'byoip_allocated_range_collections' to be a list")
        pulumi.set(__self__, "byoip_allocated_range_collections", byoip_allocated_range_collections)
        if byoip_range_id and not isinstance(byoip_range_id, str):
            raise TypeError("Expected argument 'byoip_range_id' to be a str")
        pulumi.set(__self__, "byoip_range_id", byoip_range_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="byoipAllocatedRangeCollections")
    def byoip_allocated_range_collections(self) -> Sequence['outputs.GetByoipAllocatedRangesByoipAllocatedRangeCollectionResult']:
        """
        The list of byoip_allocated_range_collection.
        """
        return pulumi.get(self, "byoip_allocated_range_collections")

    @property
    @pulumi.getter(name="byoipRangeId")
    def byoip_range_id(self) -> str:
        return pulumi.get(self, "byoip_range_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetByoipAllocatedRangesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetByoipAllocatedRangesResult(GetByoipAllocatedRangesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetByoipAllocatedRangesResult(
            byoip_allocated_range_collections=self.byoip_allocated_range_collections,
            byoip_range_id=self.byoip_range_id,
            filters=self.filters,
            id=self.id)


def get_byoip_allocated_ranges(byoip_range_id: Optional[str] = None,
                               filters: Optional[Sequence[pulumi.InputType['GetByoipAllocatedRangesFilterArgs']]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetByoipAllocatedRangesResult:
    """
    This data source provides the list of Byoip Allocated Ranges in Oracle Cloud Infrastructure Core service.

    Lists the subranges of a BYOIP CIDR block currently allocated to an IP pool.
    Each `ByoipAllocatedRange` object also lists the IP pool where it is allocated.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_byoip_allocated_ranges = oci.Core.get_byoip_allocated_ranges(byoip_range_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str byoip_range_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the `ByoipRange` resource containing the BYOIP CIDR block.
    """
    __args__ = dict()
    __args__['byoipRangeId'] = byoip_range_id
    __args__['filters'] = filters
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Core/getByoipAllocatedRanges:getByoipAllocatedRanges', __args__, opts=opts, typ=GetByoipAllocatedRangesResult).value

    return AwaitableGetByoipAllocatedRangesResult(
        byoip_allocated_range_collections=__ret__.byoip_allocated_range_collections,
        byoip_range_id=__ret__.byoip_range_id,
        filters=__ret__.filters,
        id=__ret__.id)


@_utilities.lift_output_func(get_byoip_allocated_ranges)
def get_byoip_allocated_ranges_output(byoip_range_id: Optional[pulumi.Input[str]] = None,
                                      filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetByoipAllocatedRangesFilterArgs']]]]] = None,
                                      opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetByoipAllocatedRangesResult]:
    """
    This data source provides the list of Byoip Allocated Ranges in Oracle Cloud Infrastructure Core service.

    Lists the subranges of a BYOIP CIDR block currently allocated to an IP pool.
    Each `ByoipAllocatedRange` object also lists the IP pool where it is allocated.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_byoip_allocated_ranges = oci.Core.get_byoip_allocated_ranges(byoip_range_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str byoip_range_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the `ByoipRange` resource containing the BYOIP CIDR block.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetVantagePointsResult',
    'AwaitableGetVantagePointsResult',
    'get_vantage_points',
    'get_vantage_points_output',
]

@pulumi.output_type
class GetVantagePointsResult:
    """
    A collection of values returned by getVantagePoints.
    """
    def __init__(__self__, display_name=None, filters=None, health_checks_vantage_points=None, id=None, name=None):
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if health_checks_vantage_points and not isinstance(health_checks_vantage_points, list):
            raise TypeError("Expected argument 'health_checks_vantage_points' to be a list")
        pulumi.set(__self__, "health_checks_vantage_points", health_checks_vantage_points)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        The display name for the vantage point. Display names are determined by the best information available and may change over time.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetVantagePointsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter(name="healthChecksVantagePoints")
    def health_checks_vantage_points(self) -> Sequence['outputs.GetVantagePointsHealthChecksVantagePointResult']:
        """
        The list of health_checks_vantage_points.
        """
        return pulumi.get(self, "health_checks_vantage_points")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The unique, permanent name for the vantage point.
        """
        return pulumi.get(self, "name")


class AwaitableGetVantagePointsResult(GetVantagePointsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetVantagePointsResult(
            display_name=self.display_name,
            filters=self.filters,
            health_checks_vantage_points=self.health_checks_vantage_points,
            id=self.id,
            name=self.name)


def get_vantage_points(display_name: Optional[str] = None,
                       filters: Optional[Sequence[pulumi.InputType['GetVantagePointsFilterArgs']]] = None,
                       name: Optional[str] = None,
                       opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetVantagePointsResult:
    """
    This data source provides the list of Vantage Points in Oracle Cloud Infrastructure Health Checks service.

    Gets information about all vantage points available to the user.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_vantage_points = oci.HealthChecks.get_vantage_points(display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str display_name: Filters results that exactly match the `displayName` field.
    :param str name: Filters results that exactly match the `name` field.
    """
    __args__ = dict()
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:HealthChecks/getVantagePoints:getVantagePoints', __args__, opts=opts, typ=GetVantagePointsResult).value

    return AwaitableGetVantagePointsResult(
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        health_checks_vantage_points=__ret__.health_checks_vantage_points,
        id=__ret__.id,
        name=__ret__.name)


@_utilities.lift_output_func(get_vantage_points)
def get_vantage_points_output(display_name: Optional[pulumi.Input[Optional[str]]] = None,
                              filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetVantagePointsFilterArgs']]]]] = None,
                              name: Optional[pulumi.Input[Optional[str]]] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetVantagePointsResult]:
    """
    This data source provides the list of Vantage Points in Oracle Cloud Infrastructure Health Checks service.

    Gets information about all vantage points available to the user.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_vantage_points = oci.HealthChecks.get_vantage_points(display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str display_name: Filters results that exactly match the `displayName` field.
    :param str name: Filters results that exactly match the `name` field.
    """
    ...
